@@ -41,7 +41,7 @@
   stat_df <- stat_df[-1,]
 
   cols_to_transform <- stat_df %>%
-    dplyr::select(-.data$Squad) %>% names()
+    dplyr::select(-.data[["Squad"]]) %>% names()
 
   stat_df <- stat_df %>%
     dplyr::mutate_at(.vars = cols_to_transform, .funs = function(x) {gsub(",", "", x)}) %>%
@@ -93,7 +93,7 @@
   names(stat_df) <- new_names
   stat_df <- stat_df[-1,]
 
-  stat_df <- stat_df %>% dplyr::select(-.data$Matches)
+  stat_df <- stat_df %>% dplyr::select(-.data[["Matches"]])
 
   remove_rows <- min(grep("Season", stat_df$Season)):nrow(stat_df)
 
@@ -101,10 +101,10 @@
 
   if(any(grepl("LgRank", names(stat_df)))){
     cols_to_transform <- stat_df %>%
-      dplyr::select(-.data$Season, -.data$Squad, -.data$Country, -.data$Comp, -.data$LgRank) %>% names()
+      dplyr::select(-.data[["Season"]], -.data[["Squad"]], -.data[["Country"]], -.data[["Comp"]], -.data[["LgRank"]]) %>% names()
   } else {
     cols_to_transform <- stat_df %>%
-      dplyr::select(-.data$Season, -.data$Squad, -.data$Country, -.data$Comp) %>% names()
+      dplyr::select(-.data[["Season"]], -.data[["Squad"]], -.data[["Country"]], -.data[["Comp"]]) %>% names()
   }
 
   stat_df <- stat_df %>%
@@ -159,7 +159,7 @@
   }
 
   # cols_to_transform <- df_in %>%
-  #   dplyr::select(-.data$Player, -.data$Nation, -.data$Pos, -.data$Age) %>% names()
+  #   dplyr::select(-.data[["Player"]], -.data[["Nation"]], -.data[["Pos"]], -.data[["Age"]]) %>% names()
 
   non_num_vars <- c("Player", "Nation", "Pos", "Age")
   cols_to_transform <- names(df_in)[!names(df_in) %in% non_num_vars]
@@ -197,7 +197,7 @@
     gsub("_Var", "", .) %>%
     gsub("#", "Num_", .) %>%
     gsub("%", "_percent", .) %>%
-    gsub("_Performance", "", .) %>%
+    # gsub("_Performance", "", .) %>%
     gsub("_Penalty", "", .) %>%
     gsub("1/3", "Final_Third", .) %>%
     gsub("\\+/-", "Plus_Minus", .) %>%
@@ -264,7 +264,7 @@
     clean_json <- clean_json[grep(script_name, clean_json)] %>% stringi::stri_unescape_unicode()
     clean_json <- qdapRegex::rm_square(clean_json, extract = TRUE, include.markers = TRUE) %>% unlist() %>% stringr::str_subset("\\[\\]", negate = TRUE)
 
-    out_df <- lapply(clean_json, jsonlite::fromJSON) %>% do.call("rbind", .)
+    out_df <- lapply(clean_json, .fromJSON) %>% do.call("rbind", .)
     # some outputs don't come with the season present, so add it in if not
     if(!any(grepl("season", colnames(out_df)))) {
       season_element <- page %>% rvest::html_nodes(xpath = '//*[@name="season"]') %>%
@@ -302,7 +302,7 @@
   main_url <- "https://understat.com/"
   # need to get the game IDs first, filtering out matches not yet played as these URLs will error
   games <-  .get_clean_understat_json(page_url = type_url, script_name = "datesData") %>%
-    dplyr::filter(.data$isResult)
+    dplyr::filter(.data[["isResult"]])
   # then create a chr vector of match URLs
   match_urls <- paste0(main_url, "match/", games$id)
 
@@ -397,3 +397,38 @@
   session <- rvest::session(url = page_url, ua)
   xml2::read_html(session)
 }
+
+# Use 1.8.0 version of jsonlite::fromJSON since 1.8.2's version (that uses base::url()) doesn't work for some cases
+#' @importFrom jsonlite validate parse_json
+#' @importFrom curl new_handle handle_setheaders curl
+.fromJSON <- function(txt, simplifyVector = TRUE, simplifyDataFrame = simplifyVector, simplifyMatrix = simplifyVector, flatten = FALSE, ...) {
+
+  # check type
+  if (!is.character(txt) && !inherits(txt, "connection")) {
+    stop("Argument 'txt' must be a JSON string, URL or file.")
+  }
+
+  # overload for URL or path
+  if (is.character(txt) && length(txt) == 1 && nchar(txt, type="bytes") < 2084 && !jsonlite::validate(txt)) {
+    if (grepl("^https?://", txt, useBytes=TRUE)) {
+      agent <- getOption("worldfootballR.agent", default = "RStudio Desktop (2022.7.1.554); R (4.1.1 x86_64-w64-mingw32 x86_64 mingw32)")
+      h <- curl::new_handle(useragent = agent)
+      curl::handle_setheaders(h, Accept = "application/json, text/*, */*")
+      txt <- curl::curl(txt, handle = h)
+    } else if (file.exists(txt)) {
+      # With files we can never know for sure the encoding. Lets try UTF8 first.
+      # txt <- raw_to_json(readBin(txt, raw(), file.info(txt)$size));
+      txt <- file(txt)
+    }
+  }
+
+  jsonlite::parse_json(
+    txt = txt,
+    flatten = flatten,
+    simplifyVector = simplifyVector,
+    simplifyDataFrame = simplifyDataFrame,
+    simplifyMatrix = simplifyMatrix,
+    ...
+  )
+}
+
