@@ -25,7 +25,7 @@ tm_team_transfer_balances <- function(country_name, start_year, league_url=NA) {
                         stringsAsFactors = F)
 
     tryCatch({meta_df_seasons <- meta_df %>%
-      dplyr::filter(.data$country %in% country_name, .data$season_start_year %in% start_year)}, error = function(e) {meta_df_seasons <- data.frame()})
+      dplyr::filter(.data[["country"]] %in% country_name, .data[["season_start_year"]] %in% start_year)}, error = function(e) {meta_df_seasons <- data.frame()})
 
     if(nrow(meta_df_seasons) == 0) {
       stop(glue::glue("Country {country_name} or season {start_year} not found. Check that the country and season exists at https://github.com/JaseZiv/worldfootballR_data/blob/master/raw-data/transfermarkt_leagues/main_comp_seasons.csv"))
@@ -88,12 +88,12 @@ tm_team_transfer_balances <- function(country_name, start_year, league_url=NA) {
   }
 
   all_df <- all_df %>%
-    dplyr::mutate(expenditure_euros = gsub("Expenditure: ", "", .data$expenditure_euros),
-                  income_euros = gsub("Income: ", "", .data$income_euros),
-                  avg_age_out = as.numeric(gsub(".*:","", .data$avg_age_out)),
-                  avg_age_in = as.numeric(gsub(".*:","", .data$avg_age_in))) %>%
-    dplyr::mutate(expenditure_euros = mapply(.convert_value_to_numeric, .data$expenditure_euros),
-                  income_euros = mapply(.convert_value_to_numeric, .data$income_euros))
+    dplyr::mutate(expenditure_euros = gsub("Expenditure: ", "", .data[["expenditure_euros"]]),
+                  income_euros = gsub("Income: ", "", .data[["income_euros"]]),
+                  avg_age_out = as.numeric(gsub(".*:","", .data[["avg_age_out"]])),
+                  avg_age_in = as.numeric(gsub(".*:","", .data[["avg_age_in"]]))) %>%
+    dplyr::mutate(expenditure_euros = mapply(.convert_value_to_numeric, .data[["expenditure_euros"]]),
+                  income_euros = mapply(.convert_value_to_numeric, .data[["income_euros"]]))
 
 
   return(all_df)
