@@ -298,9 +298,9 @@ test_that("fb_team_player_stats() works", {
 Sys.sleep(3)
 test_that("fb_team_match_log_stats() works", {
   testthat::skip_on_cran()
-  liv_passing_log <- fb_team_match_log_stats(team_url= "https://fbref.com/en/squads/822bd0ba/Liverpool-Stats", stat_type= 'passing', time_pause = 4)
-  expect_type(liv_passing_log, "list")
-  expect_false(nrow(liv_passing_log) == 0)
+  liv_keeper_log <- fb_team_match_log_stats(team_url= "https://fbref.com/en/squads/822bd0ba/Liverpool-Stats", stat_type= 'keeper', time_pause = 4)
+  expect_type(liv_keeper_log, "list")
+  expect_false(nrow(liv_keeper_log) == 0)
 
   # this should error because the stat type isn't available
   expect_error(fb_team_match_log_stats(team_url = "https://fbref.com/en/squads/d6a369a2/Fleetwood-Town-Stats", stat_type= 'keeper_adv', time_pause = 4))
@@ -318,3 +318,19 @@ test_that("fb_squad_wages() works", {
   expect_type(liv_wages, "list")
   expect_false(nrow(liv_wages) == 0)
 })
+
+Sys.sleep(3)
+test_that("fb_team_goal_logs() works", {
+  testthat::skip_on_cran()
+  mc_goal_log <- fb_team_goal_logs(team_url= "https://fbref.com/en/squads/b8fd03ef/Manchester-City-Stats", time_pause = 4, for_or_against = "for")
+  expect_type(mc_goal_log, "list")
+  expect_false(nrow(mc_goal_log) == 0)
+})
+
+Sys.sleep(3)
+test_that("fb_player_goal_logs() works", {
+  testthat::skip_on_cran()
+  jwp_goal_log <- fb_player_goal_logs(player_url= "https://fbref.com/en/players/3515d404/James-Ward-Prowse", time_pause = 4, goals_or_assists="goals")
+  expect_type(jwp_goal_log, "list")
+  expect_false(nrow(jwp_goal_log) == 0)
+})
